@@ -15,11 +15,13 @@ from .export import export
 from .exportdb import exportdb
 from .grep import grep
 from .help import help
+from .import_cli import import_cli
 from .info import info
 from .install_uninstall_run import install, run, uninstall
 from .keywords import keywords
 from .labels import labels
 from .list import list_libraries
+from .orphans import orphans
 from .persons import persons
 from .photo_inspect import photo_inspect
 from .places import places
@@ -74,11 +76,13 @@ for command in [
     exportdb,
     grep,
     help,
+    import_cli,
     info,
     install,
     keywords,
     labels,
     list_libraries,
+    orphans,
     persons,
     photo_inspect,
     places,
