@@ -71,6 +71,7 @@ TEMPLATE_SUBSTITUTIONS = {
     "{edited}": "True if photo has been edited (has adjustments), otherwise False; use in format '{edited?VALUE_IF_TRUE,VALUE_IF_FALSE}'",
     "{edited_version}": "True if template is being rendered for the edited version of a photo, otherwise False. ",
     "{favorite}": "Photo has been marked as favorite?; True/False value, use in format '{favorite?VALUE_IF_TRUE,VALUE_IF_FALSE}'",
+    "{created}": "Photo's creation date in ISO format, e.g. '2020-03-22'",
     "{created.date}": "Photo's creation date in ISO format, e.g. '2020-03-22'",
     "{created.year}": "4-digit year of photo creation time",
     "{created.yy}": "2-digit year of photo creation time",
@@ -88,6 +89,7 @@ TEMPLATE_SUBSTITUTIONS = {
     + "{created.strftime,%Y-%U} would result in year-week number of year: '2020-23'. "
     + "If used with no template will return null value. "
     + "See https://strftime.org/ for help on strftime templates.",
+    "{modified}": "Photo's modification date in ISO format, e.g. '2020-03-22'; uses creation date if photo is not modified",
     "{modified.date}": "Photo's modification date in ISO format, e.g. '2020-03-22'; uses creation date if photo is not modified",
     "{modified.year}": "4-digit year of photo modification time; uses creation date if photo is not modified",
     "{modified.yy}": "2-digit year of photo modification time; uses creation date if photo is not modified",
@@ -105,6 +107,7 @@ TEMPLATE_SUBSTITUTIONS = {
     + "{modified.strftime,%Y-%U} would result in year-week number of year: '2020-23'. "
     + "If used with no template will return null value. Uses creation date if photo is not modified. "
     + "See https://strftime.org/ for help on strftime templates.",
+    "{today}": "Current date in iso format, e.g. '2020-03-22'",
     "{today.date}": "Current date in iso format, e.g. '2020-03-22'",
     "{today.year}": "4-digit year of current date",
     "{today.yy}": "2-digit year of current date",
@@ -181,7 +184,8 @@ TEMPLATE_SUBSTITUTIONS = {
     "{newline}": r"A newline: '\n'",
     "{lf}": r"A line feed: '\n', alias for {newline}",
     "{cr}": r"A carriage return: '\r'",
-    "{crlf}": r"a carriage return + line feed: '\r\n'",
+    "{crlf}": r"A carriage return + line feed: '\r\n'",
+    "{tab}": r":A tab: '\t'",
     "{osxphotos_version}": f"The osxphotos version, e.g. '{__version__}'",
     "{osxphotos_cmd_line}": "The full command line used to run osxphotos",
 }
@@ -268,6 +272,11 @@ FILTER_VALUES = {
     + "slice(::-1): ['a', 'b', 'c', 'd'] => ['d', 'c', 'b', 'a']. See also sslice().",
     "sslice(start:stop:step)": "[s(tring) slice] Slice values in a list using same semantics as Python's string slicing, "
     + "e.g. sslice(1:3):'abcd => 'bc'; sslice(1:4:2): 'abcd' => 'bd', etc. See also slice().",
+    "filter(x)": "Filter list of values using predicate x; for example, `{folder_album|filter(contains Events)}` returns only folders/albums containing the word 'Events' in their path.",
+    "int": "Convert values in list to integer, e.g. 1.0 => 1. If value cannot be converted to integer, remove value from list. "
+    + "['1.1', 'x'] => ['1']. See also float.",
+    "float": "Convert values in list to floating point number, e.g. 1 => 1.0. If value cannot be converted to float, remove value from list. "
+    + "['1', 'x'] => ['1.0']. See also int.",
 }
 
 # Just the substitutions without the braces
@@ -307,6 +316,7 @@ PUNCTUATION = {
     "lf": "\n",
     "cr": "\r",
     "crlf": "\r\n",
+    "tab": "\t",
 }
 
 
@@ -329,6 +339,7 @@ class RenderOptions:
     dest_path: set to the destination path of the photo (for use by {function} template), only valid with --filename
     filepath: set to value for filepath of the exported photo if you want to evaluate {filepath} template
     quote: quote path templates for execution in the shell
+    caller: which command is calling the template (e.g. 'export')
     """
 
     none_str: str = "_"
@@ -343,6 +354,7 @@ class RenderOptions:
     dest_path: Optional[str] = None
     filepath: Optional[str] = None
     quote: bool = False
+    caller: str = "export"
 
 
 class PhotoTemplateParser:
@@ -665,16 +677,18 @@ class PhotoTemplate:
                     vals = string_test(lambda v, c: v.endswith(c))
                 elif operator == "==":
                     match = sorted(vals) == sorted(conditional_value)
-                    if (match and not negation) or (negation and not match):
-                        vals = ["True"]
-                    else:
-                        vals = []
+                    vals = (
+                        ["True"]
+                        if (match and not negation) or (negation and not match)
+                        else []
+                    )
                 elif operator == "!=":
                     match = sorted(vals) != sorted(conditional_value)
-                    if (match and not negation) or (negation and not match):
-                        vals = ["True"]
-                    else:
-                        vals = []
+                    vals = (
+                        ["True"]
+                        if (match and not negation) or (negation and not match)
+                        else []
+                    )
                 elif operator == "<":
                     vals = comparison_test(lambda v, c: v < c)
                 elif operator == "<=":
@@ -788,7 +802,9 @@ class PhotoTemplate:
                 raise ValueError(
                     "SyntaxError: filename and function must not be null with {function::filename.py:function_name}"
                 )
-            vals = self.get_template_value_function(subfield, field_arg)
+            vals = self.get_template_value_function(
+                subfield, field_arg, self.options.caller
+            )
         elif field in MULTI_VALUE_SUBSTITUTIONS or field.startswith("photo"):
             vals = self.get_template_value_multi(
                 field, subfield, path_sep=field_arg, default=default
@@ -802,10 +818,10 @@ class PhotoTemplate:
 
     def get_template_value(
         self,
-        field,
-        default,
-        subfield,
-        field_arg,
+        field: str,
+        default: List[str],
+        subfield: Optional[str],
+        field_arg: Optional[str],
     ):
         """lookup value for template field (single-value template substitutions)
 
@@ -832,38 +848,8 @@ class PhotoTemplate:
 
         # wouldn't a switch/case statement be nice...
         # handle the fields that don't require a PhotoInfo object first
-        if field == "today.date":
-            value = DateTimeFormatter(self.today).date
-        elif field == "today.year":
-            value = DateTimeFormatter(self.today).year
-        elif field == "today.yy":
-            value = DateTimeFormatter(self.today).yy
-        elif field == "today.mm":
-            value = DateTimeFormatter(self.today).mm
-        elif field == "today.month":
-            value = DateTimeFormatter(self.today).month
-        elif field == "today.mon":
-            value = DateTimeFormatter(self.today).mon
-        elif field == "today.dd":
-            value = DateTimeFormatter(self.today).dd
-        elif field == "today.dow":
-            value = DateTimeFormatter(self.today).dow
-        elif field == "today.doy":
-            value = DateTimeFormatter(self.today).doy
-        elif field == "today.hour":
-            value = DateTimeFormatter(self.today).hour
-        elif field == "today.min":
-            value = DateTimeFormatter(self.today).min
-        elif field == "today.sec":
-            value = DateTimeFormatter(self.today).sec
-        elif field == "today.strftime":
-            if default:
-                try:
-                    value = self.today.strftime(default[0])
-                except:
-                    raise ValueError(f"Invalid strftime template: '{default}'")
-            else:
-                value = None
+        if field.startswith("today"):
+            value = format_date_field(self.today, field, default)
         elif field in PUNCTUATION:
             value = PUNCTUATION[field]
         elif field == "osxphotos_version":
@@ -894,189 +880,15 @@ class PhotoTemplate:
             value = "edited_version" if self.edited_version else None
         elif field == "favorite":
             value = "favorite" if self.photo.favorite else None
-        elif field == "created.date":
-            value = DateTimeFormatter(self.photo.date).date
-        elif field == "created.year":
-            value = DateTimeFormatter(self.photo.date).year
-        elif field == "created.yy":
-            value = DateTimeFormatter(self.photo.date).yy
-        elif field == "created.mm":
-            value = DateTimeFormatter(self.photo.date).mm
-        elif field == "created.month":
-            value = DateTimeFormatter(self.photo.date).month
-        elif field == "created.mon":
-            value = DateTimeFormatter(self.photo.date).mon
-        elif field == "created.dd":
-            value = DateTimeFormatter(self.photo.date).dd
-        elif field == "created.dow":
-            value = DateTimeFormatter(self.photo.date).dow
-        elif field == "created.doy":
-            value = DateTimeFormatter(self.photo.date).doy
-        elif field == "created.hour":
-            value = DateTimeFormatter(self.photo.date).hour
-        elif field == "created.min":
-            value = DateTimeFormatter(self.photo.date).min
-        elif field == "created.sec":
-            value = DateTimeFormatter(self.photo.date).sec
-        elif field == "created.strftime":
-            if default:
-                try:
-                    value = self.photo.date.strftime(default[0])
-                except:
-                    raise ValueError(f"Invalid strftime template: '{default}'")
-            else:
-                value = None
-        elif field == "modified.date":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).date
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).date
-            )
-        elif field == "modified.year":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).year
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).year
-            )
-        elif field == "modified.yy":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).yy
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).yy
-            )
-        elif field == "modified.mm":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).mm
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).mm
-            )
-        elif field == "modified.month":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).month
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).month
-            )
-        elif field == "modified.mon":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).mon
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).mon
-            )
-        elif field == "modified.dd":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).dd
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).dd
-            )
-        elif field == "modified.dow":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).dow
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).dow
-            )
-        elif field == "modified.doy":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).doy
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).doy
-            )
-        elif field == "modified.hour":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).hour
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).hour
-            )
-        elif field == "modified.min":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).min
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).min
-            )
-        elif field == "modified.sec":
-            value = (
-                DateTimeFormatter(self.photo.date_modified).sec
-                if self.photo.date_modified
-                else DateTimeFormatter(self.photo.date).sec
-            )
-        elif field == "modified.strftime":
-            if default:
-                try:
-                    date = self.photo.date_modified or self.photo.date
-                    value = date.strftime(default[0])
-                except:
-                    raise ValueError(f"Invalid strftime template: '{default}'")
-            else:
-                value = None
-        elif field == "place.name":
-            value = self.photo.place.name if self.photo.place else None
-        elif field == "place.country_code":
-            value = self.photo.place.country_code if self.photo.place else None
-        elif field == "place.name.country":
-            value = (
-                self.photo.place.names.country[0]
-                if self.photo.place and self.photo.place.names.country
-                else None
-            )
-        elif field == "place.name.state_province":
-            value = (
-                self.photo.place.names.state_province[0]
-                if self.photo.place and self.photo.place.names.state_province
-                else None
-            )
-        elif field == "place.name.city":
-            value = (
-                self.photo.place.names.city[0]
-                if self.photo.place and self.photo.place.names.city
-                else None
-            )
-        elif field == "place.name.area_of_interest":
-            value = (
-                self.photo.place.names.area_of_interest[0]
-                if self.photo.place and self.photo.place.names.area_of_interest
-                else None
-            )
-        elif field == "place.address":
-            value = (
-                self.photo.place.address_str
-                if self.photo.place and self.photo.place.address_str
-                else None
-            )
-        elif field == "place.address.street":
-            value = (
-                self.photo.place.address.street
-                if self.photo.place and self.photo.place.address.street
-                else None
-            )
-        elif field == "place.address.city":
-            value = (
-                self.photo.place.address.city
-                if self.photo.place and self.photo.place.address.city
-                else None
-            )
-        elif field == "place.address.state_province":
-            value = (
-                self.photo.place.address.state_province
-                if self.photo.place and self.photo.place.address.state_province
-                else None
-            )
-        elif field == "place.address.postal_code":
-            value = (
-                self.photo.place.address.postal_code
-                if self.photo.place and self.photo.place.address.postal_code
-                else None
-            )
-        elif field == "place.address.country":
-            value = (
-                self.photo.place.address.country
-                if self.photo.place and self.photo.place.address.country
-                else None
-            )
-        elif field == "place.address.country_code":
-            value = (
-                self.photo.place.address.iso_country_code
-                if self.photo.place and self.photo.place.address.iso_country_code
-                else None
+        elif field.startswith("created"):
+            value = format_date_field(self.photo.date, field, default)
+        elif field.startswith("modified"):
+            # if no modified date, use photo.date
+            value = format_date_field(
+                self.photo.date_modified or self.photo.date, field, default
             )
+        elif field.startswith("place"):
+            value = get_place_value(self.photo, field)
         elif field == "searchinfo.season":
             value = self.photo.search_info.season if self.photo.search_info else None
         elif field == "exif.camera_make":
@@ -1178,6 +990,7 @@ class PhotoTemplate:
             "remove",
             "slice",
             "sslice",
+            "filter",
         ] and (args is None or not len(args)):
             raise SyntaxError(f"{filter_} requires arguments")
 
@@ -1266,12 +1079,72 @@ class PhotoTemplate:
             # slice each value in a list
             slice_ = create_slice(args)
             value = [v[slice_] for v in values]
+        elif filter_ == "filter":
+            # filter values based on a predicate
+            value = [v for v in values if self.filter_predicate(v, args)]
+        elif filter_ == "int":
+            # convert value to integer
+            value = values_to_int(values)
+        elif filter_ == "float":
+            # convert value to float
+            value = values_to_float(values)
         elif filter_.startswith("function:"):
             value = self.get_template_value_filter_function(filter_, args, values)
         else:
             value = []
         return value
 
+    def filter_predicate(self, value: str, args: str) -> bool:
+        """Return True if value passes predicate"""
+
+        # extract function name and arguments
+        if not args:
+            raise SyntaxError("Filter predicate requires arguments")
+        args = args.split(None, 1)
+        if args[0] == "not":
+            args = args[1:]
+            return not self.filter_predicate(value, " ".join(args))
+
+        predicate = args[0]
+        conditional_value = args[1].split("|")
+
+        def comparison_test(test_function):
+            """Perform numerical comparisons using test_function"""
+            # returns True if any of the values match the condition
+            try:
+                return any(
+                    bool(test_function(float(value), float(c)))
+                    for c in conditional_value
+                )
+            except ValueError as e:
+                raise SyntaxError(
+                    f"comparison operators may only be used with values that can be converted to numbers: {vals} {conditional_value}"
+                ) from e
+
+        predicate_is_true = False
+        if predicate == "contains":
+            predicate_is_true = any(c in value for c in conditional_value)
+        elif predicate == "endswith":
+            predicate_is_true = any(value.endswith(c) for c in conditional_value)
+        elif predicate in ["matches", "=="]:
+            predicate_is_true = any(value == c for c in conditional_value)
+        elif predicate == "startswith":
+            predicate_is_true = any(value.startswith(c) for c in conditional_value)
+        elif predicate == "!=":
+            predicate_is_true = any(value != c for c in conditional_value)
+        elif predicate == "<":
+            predicate_is_true = comparison_test(lambda v, c: v < c)
+        elif predicate == "<=":
+            predicate_is_true = comparison_test(lambda v, c: v <= c)
+        elif predicate == ">":
+            predicate_is_true = comparison_test(lambda v, c: v > c)
+        elif predicate == ">=":
+            predicate_is_true = comparison_test(lambda v, c: v >= c)
+        else:
+            raise SyntaxError(f"Invalid predicate: {predicate}")
+
+        return predicate_is_true
+
     def get_template_value_multi(self, field, subfield, path_sep, default):
         """lookup value for template field (multi-value template substitutions)
 
@@ -1459,10 +1332,17 @@ class PhotoTemplate:
 
     def get_template_value_function(
         self,
-        subfield,
-        field_arg,
+        subfield: str,
+        field_arg: Optional[str],
+        caller: str,
     ):
-        """Get template value from external function"""
+        """Get template value from external function
+
+        Args:
+            subfield: the filename and function name in for filename.py::function
+            field_arg: the argument to pass to the function
+            caller: the calling source of the template ('export' or 'import')
+        """
 
         if "::" not in subfield:
             raise ValueError(
@@ -1481,8 +1361,17 @@ class PhotoTemplate:
             # if no uuid, then template is being validated but not actually run
             # so don't run the function
             values = []
-        else:
+        elif caller in ["export", "query"]:
+            # function signature is:
+            # def example(photo: PhotoInfo, options: ExportOptions, args: Optional[str] = None, **kwargs) -> Union[List, str]:
             values = template_func(self.photo, options=self.options, args=field_arg)
+        elif caller == "import":
+            # function signature is:
+            # def example(filepath: pathlib.Path, args: Optional[str] = None, **kwargs) -> Union[List, str]:
+            # the PhotoInfoFromFile class used by import sets `path` to the path of the file being imported
+            values = template_func(pathlib.Path(self.photo.path), args=field_arg)
+        else:
+            raise ValueError(f"Unhandled caller: {caller}")
 
         if not isinstance(values, (str, list)):
             raise TypeError(
@@ -1627,22 +1516,20 @@ def _get_pathlib_value(field, value, quote):
     parts = field.split(".")
 
     if len(parts) == 1:
-        return shlex.quote(value) if quote else value
+        return shlex.quote(str(value)) if quote else str(value)
 
-    if len(parts) > 2:
-        raise ValueError(f"Illegal value for path template: {field}")
-
-    path = parts[0]
-    attribute = parts[1]
     path = pathlib.Path(value)
-    try:
-        val = getattr(path, attribute)
-        val_str = str(val)
-        if quote:
-            val_str = shlex.quote(val_str)
-        return val_str
-    except AttributeError:
-        raise ValueError("Illegal value for path template: {attribute}")
+    for attribute in parts[1:]:
+        try:
+            val = getattr(path, attribute)
+            path = pathlib.Path(val)
+        except AttributeError as e:
+            raise ValueError(f"Illegal value for filepath template: {attribute}") from e
+
+    val_str = str(val)
+    if quote:
+        val_str = shlex.quote(val_str)
+    return val_str
 
 
 def format_str_value(value, format_str):
@@ -1655,19 +1542,18 @@ def format_str_value(value, format_str):
 
 def _get_album_by_name(photo, album):
     """Finds first album named album that photo is in and returns the AlbumInfo object, otherwise returns None"""
-    for album_info in photo.album_info:
-        if album_info.title == album:
-            return album_info
-    return None
+    return next(
+        (album_info for album_info in photo.album_info if album_info.title == album),
+        None,
+    )
 
 
 def _get_album_by_path(photo, folder_album_path):
     """finds the first album whose folder_album path matches and folder_album_path and returns the AlbumInfo object, otherwise, returns None"""
-
     for album_info in photo.album_info:
         # following code is how {folder_album} builds the folder path
         folder = "/".join(sanitize_dirname(f) for f in album_info.folder_names)
-        folder += "/" + sanitize_dirname(album_info.title)
+        folder += f"/{sanitize_dirname(album_info.title)}"
         if folder_album_path.endswith(folder):
             return album_info
     return None
@@ -1712,3 +1598,100 @@ def create_slice(args):
     else:
         raise SyntaxError(f"Invalid slice: {args}")
     return slice(start, end, step)
+
+
+def values_to_int(values: List[str]) -> List[str]:
+    """Convert a list of strings to str representation of ints, if possible, otherwise strip values from list"""
+    int_values = []
+    for v in values:
+        with suppress(ValueError):
+            int_values.append(str(int(float(v))))
+    return int_values
+
+
+def values_to_float(values: List[str]) -> List[str]:
+    """Convert a list of strings to str representation of float, if possible, otherwise strip values from list"""
+    float_values = []
+    for v in values:
+        with suppress(ValueError):
+            float_values.append(str(float(v)))
+    return float_values
+
+
+def format_date_field(dt: datetime.datetime, field: str, args: List[str]) -> str:
+    """Format a date template field in format 'created', 'create.year' etc.
+
+    Args:
+        dt: datetime object
+        field: the field to format, e.g. 'created.year', 'today.strftime'
+        args: the argument to the field, e.g. '%Y' for strftime
+    """
+    fields = field.split(".")
+    if len(fields) == 1:
+        # no subfield, just return the formatted date str
+        return dt.date().isoformat()
+    if len(fields) > 2:
+        raise ValueError(f"Unhandled template value: {field}")
+    subfield = fields[1]
+    if subfield == "strftime":
+        if not args:
+            return None
+        try:
+            return dt.strftime(args[0])
+        except:
+            raise ValueError(f"Invalid strftime template: '{args}'")
+    else:
+        try:
+            return getattr(DateTimeFormatter(dt), subfield)
+        except AttributeError as e:
+            raise ValueError(f"Unhandled template value: {field}") from e
+
+
+def get_place_value(photo: "PhotoInfo", field: str):
+    """Get the value of a 'place' field by attribute
+
+    Args:
+        photo: the PhotoInfo object
+        field: the field to get, e.g. 'place.name'
+    """
+    if not photo.place:
+        return None
+
+    fields = field.split(".")
+    if len(fields) < 2:
+        raise ValueError(f"Invalid place field: {field}")
+    subfields = fields[1:]
+    if subfields[0] in ["name", "country_code"] and len(subfields) == 1:
+        return getattr(photo.place, subfields[0]) or None
+    elif subfields[0] == "name" and len(subfields) > 1:
+        if subfields[1] == "country":
+            return photo.place.names.country[0] if photo.place.names.country else None
+        elif subfields[1] == "state_province":
+            return (
+                photo.place.names.state_province[0]
+                if photo.place.names.state_province
+                else None
+            )
+        elif subfields[1] == "city":
+            return photo.place.names.city[0] if photo.place.names.city else None
+        elif subfields[1] == "area_of_interest":
+            return (
+                photo.place.names.area_of_interest[0]
+                if photo.place.names.area_of_interest
+                else None
+            )
+    elif subfields[0] == "address":
+        if len(subfields) == 1:
+            return photo.place.address_str
+        elif subfields[1] in [
+            "street",
+            "city",
+            "state_province",
+            "postal_code",
+            "country",
+        ]:
+            return getattr(photo.place.address, subfields[1]) or None
+        elif subfields[1] == "country_code":
+            return photo.place.address.iso_country_code or None
+    # did not find a match
+    raise ValueError(f"Unhandled template value: {field}")
